package query

import (
	"github.com/odysseus/service-registry/common"
	"github.com/redis/go-redis/v9"
	"sort"
)

type WorkerInfo struct {
	// worker specific info
	HearBeat       int64    `redis:"heartbeat" json:"heartbeat"`
	ActiveNM       []string `redis:"active_nm" json:"active_nm"`
	MinerAddress   string   `redis:"miner_address" json:"miner_address"`
	BenefitAddress string   `redis:"benefit_address" json:"benefit_address"`
	IP             string   `redis:"ip" json:"ip"`
	Nonce          int64    `redis:"nonce" json:"nonce"`
}

type workerQuery struct {
	baseService
}

func getWorkerQuery(rdb *redis.Client) ServiceQuery {
	return workerQuery{
		baseService{
			rdb:     rdb,
			service: common.SERVICE_WORKER,
		},
	}
}

func (g workerQuery) List() ([]string, error) {
	all, err := getAll(g.rdb, g.service)
	if err != nil {
		return nil, err
	}
	sort.Sort(ServiceInfoList(all))
	var res []string
	for _, v := range all {
		res = append(res, string(v.Message()))
	}
	return res, nil
}

func (g workerQuery) ListByPage(pageSize int, pageNum int) ([]string, int, error) {
	all, err := getAll(g.rdb, g.service)
	if err != nil {
		return nil, 0, err
	}
	sort.Sort(ServiceInfoList(all))
	start := pageSize * pageNum
	end := start + pageSize
	if len(all) < end {
		end = len(all)
	}
	var res []string
	for _, v := range all[start:end] {
		res = append(res, string(v.Message()))
	}
	return res, len(all), nil
}
